.. snplib documentation master file, created by
   sphinx-quickstart on Mon Jan 27 16:45:53 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to snplib's documentation!
==================================

.. toctree::
   :maxdepth: 2

   intro
   install
   usage
   examples
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
